==> 0.0.1.tar.gz: lib/spark_verification.dart <==
import 'package:spark_form/spark.dart';

enum VerifyType {
  /// verfiy value after changed
  change,

  /// verfiy value after blur
  blur,

  /// include change and blur
  all,
}

abstract class SparkVerification {
  SparkVerification({
    required this.errorMessage,
    required this.type,
    this.strategy,
  });

  /// verify error message
  String errorMessage;

  /// validate type
  VerifyType? type;

  /// validate strategy
  ///
  FormStrategy? strategy;

  /// validate rule
  ValidateResult validate(dynamic value, String fieldName);
}

class SparkLengthVerification extends SparkVerification {
  int? length;

  SparkLengthVerification.length(
    this.length, {
    required String errorMessage,
    required VerifyType? type,
    FormStrategy? strategy = FormStrategy.limit,
  }) : super(
          errorMessage: errorMessage,
          type: type,
          strategy: strategy,
        );

  @override
  ValidateResult validate(dynamic value, String fieldName) {
    return ValidateResult.from(
      errorMessage: errorMessage,
      fieldName: fieldName,
      success: value.length <= length,
      strategy: strategy,
    );
  }
}

class SparkFormatVerification extends SparkVerification {
  RegExp? rule;

  /// valify result by regexp
  SparkFormatVerification.form(
    this.rule, {
    required String errorMessage,
    required VerifyType? type,
    FormStrategy? strategy = FormStrategy.limit,
  }) : super(
          errorMessage: errorMessage,
          type: type,
          strategy: strategy,
        );

  @override
  ValidateResult validate(dynamic value, String fieldName) {
    return ValidateResult.from(
        errorMessage: errorMessage,
        fieldName: fieldName,
        success: rule!.hasMatch(value),
        strategy: strategy);
  }
}

class ValidateResult {
  ValidateResult.from({
    this.errorMessage,
    this.fieldName,
    required this.success,
    this.strategy,
  });

  /// result tip message
  String? errorMessage;

  /// result
  bool success;

  /// check field
  String? fieldName;

  /// use strategy type
  FormStrategy? strategy;
}

==> 0.0.2.tar.gz: lib/spark_verification.dart <==
import 'package:spark_form/spark.dart';

enum VerifyType {
  /// verfiy value after changed
  change,

  /// verfiy value after blur
  blur,

  /// include change and blur
  all,
}

abstract class SparkVerification {
  SparkVerification({
    required this.errorMessage,
    required this.type,
    this.strategy,
  });

  /// verify error message
  String errorMessage;

  /// validate type
  VerifyType? type;

  /// validate strategy
  ///
  FormStrategy? strategy;

  /// validate rule
  ValidateResult validate(dynamic value, String fieldName, VerifyType? type);
}

class SparkLengthVerification extends SparkVerification {
  int? length;

  SparkLengthVerification.length(
    this.length, {
    required String errorMessage,
    required VerifyType? type,
    FormStrategy? strategy = FormStrategy.limit,
  }) : super(
          errorMessage: errorMessage,
          type: type,
          strategy: strategy,
        );

  @override
  ValidateResult validate(dynamic value, String fieldName, VerifyType? type) {
    return ValidateResult.from(
      errorMessage: errorMessage,
      fieldName: fieldName,
      success: value.length <= length,
      strategy: strategy,
      type: type,
    );
  }
}

class SparkFormatVerification extends SparkVerification {
  RegExp? rule;

  /// valify result by regexp
  SparkFormatVerification.form(
    this.rule, {
    required String errorMessage,
    required VerifyType? type,
    FormStrategy? strategy = FormStrategy.limit,
  }) : super(
          errorMessage: errorMessage,
          type: type,
          strategy: strategy,
        );

  /// number only
  SparkFormatVerification.number({
    required String errorMessage,
    required VerifyType? type,
    FormStrategy? strategy = FormStrategy.limit,
  })  : rule = RegExp(r'^([0-9]{1,})+$|^([0-9]+\.)+$|^([0-9]+\.+[0-9]{1,})+$'),
        super(
          errorMessage: errorMessage,
          type: type,
          strategy: strategy,
        );

  @override
  ValidateResult validate(dynamic value, String fieldName, VerifyType? type) {
    return ValidateResult.from(
      errorMessage: errorMessage,
      fieldName: fieldName,
      success: emptyOrNullString(value) || rule!.hasMatch(value),
      strategy: strategy,
      type: type,
    );
  }
}

class SparkRequiredVerification extends SparkVerification {
  SparkRequiredVerification.required({
    required String errorMessage,
    required VerifyType? type,
    FormStrategy? strategy = FormStrategy.limit,
  }) : super(
          errorMessage: errorMessage,
          type: type,
          strategy: strategy,
        );

  @override
  ValidateResult validate(value, String fieldName, VerifyType? type) {
    bool _result = value != null;
    if (value is List<SparkFormDataChangeImp>) {
      _result = value.any((element) => element.needSelected);
    }
    if (value is String) {
      _result = !emptyOrNullString(value);
    }
    return ValidateResult.from(
      errorMessage: errorMessage,
      fieldName: fieldName,
      success: _result,
      strategy: strategy,
      type: type,
    );
  }
}

class ValidateResult {
  ValidateResult.from({
    this.errorMessage,
    this.fieldName,
    required this.success,
    this.type,
    this.strategy,
  });

  /// result tip message
  String? errorMessage;

  /// result
  bool success;

  /// check type
  VerifyType? type;

  /// check field
  String? fieldName;

  /// use strategy type
  FormStrategy? strategy;
}
